<data-masking> Expressions that
return a logical vector, defined in terms of the variables in .data. If
multiple expressions are included, they are combined with the & operator.
To combine expressions using | instead, wrap them in when_any(). Only
rows for which all expressions evaluate to TRUE are kept (for filter())
or dropped (for filter_out()).
.by
<tidy-select> Optionally, a selection of columns to
group by for just this operation, functioning as an alternative to group_by(). For
details and examples, see ?dplyr_by.