- .data
A lazy_dt().
- ...
<data-masking> Name-value pairs of
summary functions. The name will be the name of the variable in the result.
The value can be:
A vector of length 1, e.g. min(x), n(), or sum(is.na(y)).
A data frame with 1 row, to add multiple columns from a single expression.
- .by
<tidy-select> Optionally, a selection of columns to
group by for just this operation, functioning as an alternative to group_by(). For
details and examples, see ?dplyr_by.
- .groups
Grouping structure of the
result.
"drop_last": drops the last level of grouping. This was the
only supported option before version 1.0.0.
"drop": All levels of grouping are dropped.
"keep": Same grouping structure as .data.
"rowwise": Each row is its own group.
When .groups is not specified, it is set to "drop_last" for a grouped
data frame, and "keep" for a rowwise data frame. In addition, a message
informs you of how the result will be grouped unless the result is
ungrouped, the option "dplyr.summarise.inform" is set to FALSE, or when
summarise() is called from a function in a package.